@@ -14,6 +14,12 @@ DATE_PATTERNS = [
     {"label": "DATE", "pattern": [{"SHAPE": "dddd"}, {"ORTH": "to"}, {"SHAPE": "dddd"}]},  # 1805 to 1860
 ]
 
+COLLECTION_NAME_PATTERNS = [
+    # TODO: use 'POS': 'PROPN' here instead of IS_TITLE: True for better detection of proper nouns
+    {"label": "ORG", "pattern": [{'IS_TITLE': True, 'OP': '+'}, {'LOWER': 'collection'}]},  # Sforza collection
+    {"label": "ORG", "pattern": [{'IS_TITLE': True, 'OP': '+'}, {'LOWER': 'archive'}]},  # Charles Urban archive
+]
+
 ### USEFUL CONSTANTS
 
 ORDINALS = [
@@ -24,6 +30,10 @@ ORDINALS = [
     "seventeenth", "eighteenth", "nineteenth", "twentieth", "twenty-first"
 ]
 
+ROYAL_TITLES = [
+    "king", "queen", "prince", "princess", "emperor", "empress"
+]
+
 ### SPACY TO HERITAGECONNECTOR ENTITY MAPPING
 ### This allows us to map multiple Spacy NER classes to one class, in the case that we don't need the 
 ### detail of specific classes. Also includes identity mappings. `set(SPACY_TO_HC_ENTITY_MAPPING.values())`
